# <img src='https://0000.us/klatchat/app/files/neon_images/icons/neon_skill.png' card_color="#FF8600" width="50" style="vertical-align:bottom">Device Control Center

## Summary

Handles system-wide settings and controls.

## Description

Device Control skill handles global core configuration and OS interactions (via messagebus/PHAL service).

## Examples

- "Skip wake words."
- "Require wake words."
- "I want you to exit."
- "I want you to shut down."
- "I want you to restart."

## Contact Support

Use the [link](https://neongecko.com/ContactUs) or [submit an issue on GitHub](https://help.github.com/en/articles/creating-an-issue)

## Credits
[NeonGeckoCom](https://github.com/NeonGeckoCom)
[NeonDaniel](https://github.com/NeonDaniel)
[reginaneon](https://github.com/reginaneon)

## Category
**Configuration**
Daily

## Tags
#NeonGecko Original
#NeonAI
#controls
#device
#wake words
#power
#settings




